==> str_to_obj-2023.1-py3-none-any.whl: str_to_obj/main.py <==
# Copyright CNRS/Inria/UNS
# Contributor(s): Eric Debreuve (since 2023)
#
# eric.debreuve@cnrs.fr
#
# This software is governed by the CeCILL  license under French law and
# abiding by the rules of distribution of free software.  You can  use,
# modify and/ or redistribute the software under the terms of the CeCILL
# license as circulated by CEA, CNRS and INRIA at the following URL
# "http://www.cecill.info".
#
# As a counterpart to the access to the source code and  rights to copy,
# modify and redistribute granted by the license, users are provided only
# with a limited warranty  and the software's author,  the holder of the
# economic rights,  and the successive licensors  have only  limited
# liability.
#
# In this respect, the user's attention is drawn to the risks associated
# with loading,  using,  modifying and/or developing or reproducing the
# software by the user in light of its specific status of free software,
# that may mean  that it is complicated to manipulate,  and  that  also
# therefore means  that it is reserved for developers  and  experienced
# professionals having in-depth computer knowledge. Users are therefore
# encouraged to load and test the software's suitability as regards their
# requirements in conditions enabling the security of their systems and/or
# data to be ensured and,  more generally, to use and operate it in the
# same conditions as regards security.
#
# The fact that you are presently reading this means that you have had
# knowledge of the CeCILL license and that you accept its terms.

import ast as bstr
from types import NoneType
from typing import Any

from str_to_obj.task.casting import CastValue
from str_to_obj.type.hint import any_hint_h, hint_tree_t

# TRUE_VALUES = ("true", "yes", "on")
# FALSE_VALUES = ("false", "no", "off")


def AsInterpretedObject(
    string: str,
    /,
    *,
    expected_type: any_hint_h | hint_tree_t | type[NoneType] = None,
) -> tuple[Any, list[str]]:
    """
    expected_type: Must not be passed explicitly as None since None is interpreted as
    "no specific expected type". When expecting None, pass NoneType.
    """
    if expected_type is NoneType:
        if string.lower() == "none":
            issues = []
        else:
            issues = [f'{string}: Invalid value; Expected="NONE" or "None" or "none".']
        return None, issues

    try:
        value = bstr.literal_eval(string)
    except (SyntaxError, ValueError):
        value = string

    if expected_type is None:
        return value, []

    return CastValue(value, expected_type)

==> str_to_obj-2024.1-py3-none-any.whl: str_to_obj/main.py <==
# Copyright CNRS/Inria/UNS
# Contributor(s): Eric Debreuve (since 2023)
#
# eric.debreuve@cnrs.fr
#
# This software is governed by the CeCILL  license under French law and
# abiding by the rules of distribution of free software.  You can  use,
# modify and/ or redistribute the software under the terms of the CeCILL
# license as circulated by CEA, CNRS and INRIA at the following URL
# "http://www.cecill.info".
#
# As a counterpart to the access to the source code and  rights to copy,
# modify and redistribute granted by the license, users are provided only
# with a limited warranty  and the software's author,  the holder of the
# economic rights,  and the successive licensors  have only  limited
# liability.
#
# In this respect, the user's attention is drawn to the risks associated
# with loading,  using,  modifying and/or developing or reproducing the
# software by the user in light of its specific status of free software,
# that may mean  that it is complicated to manipulate,  and  that  also
# therefore means  that it is reserved for developers  and  experienced
# professionals having in-depth computer knowledge. Users are therefore
# encouraged to load and test the software's suitability as regards their
# requirements in conditions enabling the security of their systems and/or
# data to be ensured and,  more generally, to use and operate it in the
# same conditions as regards security.
#
# The fact that you are presently reading this means that you have had
# knowledge of the CeCILL license and that you accept its terms.

import ast as bstr
from types import NoneType
from typing import Any

from str_to_obj.task.casting import CastValue
from str_to_obj.type.hint_tree import any_hint_h, hint_tree_t


def ObjectFromStr(
    string: str,
    /,
    *,
    expected_type: any_hint_h | hint_tree_t | type[NoneType] = None,
) -> tuple[Any, list[str]]:
    """
    expected_type: Must not be passed explicitly as None since None is interpreted as
    "no specific expected type". When expecting None, pass NoneType.
    """
    if expected_type is NoneType:
        if string.lower() == "none":
            issues = []
        else:
            issues = [f'{string}: Invalid value; Expected="NONE" or "None" or "none".']
        return None, issues

    try:
        value = bstr.literal_eval(string)
    except (SyntaxError, ValueError):
        value = string

    if expected_type is None:
        return value, []

    return CastValue(value, expected_type)
